@@ -31,6 +31,5 @@ s3_strip_class_impl <- function(x) {
 }
 
 is_s3_method <- function(x) {
-  # Deal with objects starting with ".", e.g. .this
-  withCallingHandlers(utils::isS3method(x), error = ~FALSE)
+  ifelse(startsWith(x, "."), FALSE, utils::isS3method(x))
 }
